from scenarios.stables import ScenarioStables
from scenarios.pc_house import ScenarioPCHouse
from scenarios.town_center import ScenarioTownCenter
from meta import util


class NavSystem(object):
    def __init__(self, PC):
        """
        All the quest markers
        All the scenarios
        """

        # Scenarios - Starter Village
        self.stables = ScenarioStables(self, PC)
        self.town_center = ScenarioTownCenter(self, PC)
        self.pc_house = ScenarioPCHouse(self, PC)
        self.docks = None
        self.mentor_mannor = None
        self.village_gate = None
        self.lake = None

        # Scenarios - Cave
        self.cave_entrance = None
        self.narrow_path = None
        self.large_chamber = None
        self.hidden_room = None
        self.temple_entrance = None
        self.temple_sanctuary = None
        self.ritual = None

        # Scenarios - Great Forest
        self.tavern = None

        # Quest Markers - Starter Village
        self.stables_cleared = False
        self.town_center_cleared = False
        self.pc_house_cleared = False
        self.docks_cleared = False
        self.mentor_mannor_cleared = False
        self.village_gate_cleared = False
        self.lake_cleared = False

        # Quest Markers - Cave
        self.cave_entrance_cleared = False
        self.narrow_path_cleared = False
        self.large_chamber_cleared = False
        self.hidden_room_cleared = False
        self.temple_entrance_cleared = False
        self.temple_sanctuary_cleared = False
        self.ritual_cleared = False

        # Quest Markers - Great Forest
        self.tavern_cleared = False

        # Meta
        self.current_area = self.stables

    def check_adjacencies(self):

        # Starter Village
        if self.current_area == self.stables:
            return self.town_center, self.pc_house

        elif self.current_area == self.town_center:
            return self.docks, self.stables, self.mentor_mannor, self.village_gate

        elif self.current_area == self.pc_house:
            return self.stables, self.docks

        elif self.current_area == self.docks:
            return self.town_center, self.pc_house

        elif self.current_area == self.mentor_mannor:
            return self.town_center

        elif self.current_area == self.village_gate:
            return self.town_center, self.lake

        # Lake
        elif self.current_area == self.lake:
            return self.village_gate, self.cave_entrance, self.tavern

        # Cave

        elif self.current_area == self.cave_entrance:
            return self.lake, self.narrow_path

        elif self.current_area == self.narrow_path:
            return self.cave_entrance, self.large_chamber

        elif self.current_area == self.large_chamber:
            return self.narrow_path, self.hidden_room, self.temple_entrance

        elif self.current_area == self.hidden_room:
            return self.large_chamber

        elif self.current_area == self.temple_entrance:
            return self.large_chamber, self.temple_sanctuary

        elif self.current_area == self.temple_sanctuary:
            return self.temple_entrance, self.ritual

        elif self.current_area == self.ritual:
            return self.town_center, self.pc_house

    def travel(self):
        """
        Enumerated adjacent areas
        Visited status
        Pre-reqs

        """
        ev = util.EventHandler()

        # Print the options
        print("\nPlease select an option:")
        adjacent = self.check_adjacencies()
        for i, a in enumerate(adjacent):


            visited = "(Unvisited)"
            if a.flag_visited:
                visited = "(Visited)"
            print(i+1, ":", a.name, visited)

        # Wait for input
        ev.wait_for_user()

        # Captures the keypress from the user
        player_input = ev.key_pressed
        print("\n\n", player_input)

        # Subtract player input by 1 to get index
        # TODO try/catch block on input
        player_input = int(player_input) - 1

        util.clear()

        # Execute the start method of the place we're going
        adjacent[player_input].start()


